@@ -37,7 +37,7 @@ namespace Rosegarden
 
 class CountdownBar : public TQFrame
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     CountdownBar(TQWidget *parent, int width, int height);
