@@ -1,5 +1,3 @@
-/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
-
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
@@ -1810,7 +1808,7 @@ void MatrixView::slotVerticalScrollPianoKeyboard(int y)
 
 void MatrixView::slotInsertNoteFromAction()
 {
-    const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
+    const TQObject *s = sender();
     TQString name = s->name();
 
     Segment &segment = *getCurrentSegment();
@@ -2017,7 +2015,7 @@ MatrixView::slotSetSnapFromIndex(int s)
 void
 MatrixView::slotSetSnapFromAction()
 {
-    const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
+    const TQObject *s = sender();
     TQString name = s->name();
 
     if (name.left(5) == "snap_") {
@@ -2219,7 +2217,7 @@ MatrixView::initZoomToolbar()
     m_hZoomSlider = new ZoomSlider<double>
                     (zoomSizes, -1, Qt::Horizontal, zoomToolbar, "tde toolbar widget");
     m_hZoomSlider->setTracking(true);
-    m_hZoomSlider->setFocusPolicy(TQ_NoFocus);
+    m_hZoomSlider->setFocusPolicy(TQWidget::NoFocus);
 
     m_zoomLabel = new TQLabel(zoomToolbar, "tde toolbar widget");
     m_zoomLabel->setIndent(10);
@@ -2948,7 +2946,7 @@ MatrixView::slotStepByStepTargetRequested(TQObject *obj)
         MATRIX_DEBUG << "WARNING: No toggle_step_by_step action" << endl;
         return ;
     }
-    action->setChecked(TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(this));
+    action->setChecked(obj == this);
 }
 
 void
