@@ -185,7 +185,7 @@ extern "C" {
 #endif
 
 class KlearlookStyle : public TDEStyle {
-        Q_OBJECT
+        TQ_OBJECT
   
 
     public:
@@ -252,11 +252,11 @@ class KlearlookStyle : public TDEStyle {
                              const TQColor &fill, const TQColor *custom = NULL, bool light = false ) const;
         void drawLightBevelButton( TQPainter *p, const TQRect &r, const TQColorGroup &cg, TQStyle::SFlags flags, bool useGrad, ERound round,
                                    const TQColor &fill, const TQColor *custom = NULL, bool light = false ) const;
-        void drawArrow( TQPainter *p, const TQRect &r, const TQColorGroup &cg, TQStyle::SFlags flags, TQStyle::TQ_PrimitiveElement pe,
+        void drawArrow( TQPainter *p, const TQRect &r, const TQColorGroup &cg, TQStyle::SFlags flags, TQStyle::PrimitiveElement pe,
                         bool small = false, bool checkActive = false ) const;
-        void drawPrimitive( TQ_PrimitiveElement, TQPainter *, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &, const TQColorGroup &, SFlags = Style_Default,
+        void drawPrimitive( PrimitiveElement, TQPainter *, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &, const TQColorGroup &, SFlags = Style_Default,
                             const TQStyleOption & = TQStyleOption::Default ) const;
-        void drawPrimitiveMenu( TQ_PrimitiveElement, TQPainter *, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &, const TQColorGroup &, SFlags = Style_Default,
+        void drawPrimitiveMenu( PrimitiveElement, TQPainter *, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &, const TQColorGroup &, SFlags = Style_Default,
                                 const TQStyleOption & = TQStyleOption::Default ) const;
         void drawTDEStylePrimitive( TDEStylePrimitive kpe, TQPainter* p, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &r,
                                   const TQColorGroup &cg, SFlags flags, const TQStyleOption &opt, const TQWidget* widget = 0 ) const;
