@@ -441,7 +441,7 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
 
             TQDataStream reply(replyData, IO_ReadOnly);
             TQString connection;
-            if (replyType == TQSTRING_OBJECT_NAME_STRING) {
+            if (replyType == "TQString") {
                 reply >> connection;
                 list.append(connection);
             }
