@@ -1,5 +1,3 @@
-/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
-
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
@@ -244,8 +242,8 @@ bool
 AudioFaderBox::owns(const TQObject *object)
 {
     return (object &&
-            ((TQT_BASE_OBJECT(object->parent()) == TQT_BASE_OBJECT(this)) ||
-             (object->parent() && (TQT_BASE_OBJECT(object->parent()->parent()) == TQT_BASE_OBJECT(this)))));
+            ((object->parent() == this) ||
+             (object->parent() && (object->parent()->parent() == this))));
 }
 
 void
